@@ -1,18 +1,19 @@
 package Perinci::CmdLine::Plugin::DumpRes;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-08-06'; # DATE
-our $DIST = 'Perinci-CmdLine-Lite'; # DIST
-our $VERSION = '1.907'; # VERSION
-
-# IFUNBUILT
-# use strict;
-# use warnings;
-# END IFUNBUILT
+# put pragmas + Log::ger here
+use strict;
+use warnings;
 use Log::ger;
-
 use parent 'Perinci::CmdLine::PluginBase';
 
+# put other modules alphabetically here
+
+# put global variables alphabetically here
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-01'; # DATE
+our $DIST = 'Perinci-CmdLine-Lite'; # DIST
+our $VERSION = '1.908'; # VERSION
+
 sub meta {
     return {
         summary => 'Dump result ($r->{res}), by default after action',
@@ -45,7 +46,7 @@ Perinci::CmdLine::Plugin::DumpRes
 
 =head1 VERSION
 
-This document describes version 1.907 of Perinci::CmdLine::Plugin::DumpRes (from Perl distribution Perinci-CmdLine-Lite), released on 2021-08-06.
+This document describes version 1.908 of Perinci::CmdLine::Plugin::DumpRes (from Perl distribution Perinci-CmdLine-Lite), released on 2021-10-01.
 
 =head1 SYNOPSIS
 
@@ -69,6 +70,9 @@ If you want to dump at different events:
      ],
  );
 
+For list of plugin events available, see L<Perinci::CmdLine::Base/"Plugin
+events">.
+
 =head1 DESCRIPTION
 
 =for Pod::Coverage ^(.+)$
@@ -81,6 +85,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Lite>
@@ -89,15 +121,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
